@@ -34,6 +34,7 @@ Main code for tkinter windows.
 import os
 import inspect
 import threading
+import signal
 from dataclasses import dataclass
 import tkinter as tk
 from tkinter import DISABLED, NORMAL
@@ -43,14 +44,14 @@ from powermolegui.lib.application import application
 from powermolegui.lib.frames import MainFrame, CommandFrame
 from powermolegui.lib.helpers import ItemsGenerator, parse_configuration_file
 
-__author__ = '''Vincent Schouten <inquiry@intoreflection.co>'''
+__author__ = '''Vincent Schouten <powermole@protonmail.com>'''
 __docformat__ = '''google'''
 __date__ = '''08-10-2020'''
 __copyright__ = '''Copyright 2021, Vincent Schouten'''
 __credits__ = ["Vincent Schouten"]
 __license__ = '''MIT'''
 __maintainer__ = '''Vincent Schouten'''
-__email__ = '''<inquiry@intoreflection.co>'''
+__email__ = '''<powermole@protonmail.com>'''
 __status__ = '''Development'''  # "Prototype", "Development", "Production".
 
 # Constants regarding powermole window for non-retina (generic) screens
@@ -91,6 +92,7 @@ class MainWindow(tk.Tk, LoggerMixin):  # pylint: disable=too-many-instance-attri
         """Instantiates the main window object."""
         tk.Tk.__init__(self, *args, **kwargs)
         LoggerMixin.__init__(self)
+        signal.signal(signal.SIGINT, self._signal_handler)
         self.scale = 0
         self._script_path = self._determine_script_path()
         self._set_title_icon()
@@ -113,6 +115,10 @@ class MainWindow(tk.Tk, LoggerMixin):  # pylint: disable=too-many-instance-attri
         self.canvas_items = None  # holds canvas items; generated by (Canvas)ItemGenerator
         self.instructor = None  # holds *Instructor object which provides 'send command' and 'send file' functions
 
+    def _signal_handler(self, signum, frame):  # pylint: disable=unused-argument
+        """Handles the SIGINT generated by an user when hitting Ctrl+C in the shell."""
+        self.stop_application()
+
     def _determine_script_path(self):  # pylint: disable=no-self-use
         running_script = inspect.getframeinfo(inspect.currentframe()).filename  # /powermolegui/lib/windows.py
         running_script_dir = os.path.dirname(os.path.abspath(running_script))
